DELETE: chat.json
-----------------

It means that one of participants wants to close chat. As a result all undelivered messages are going to
deliver and chat completely removing from the Server.

.. toctree::
   :maxdepth: 2
   :titlesonly:

   Request
   Response
